# Flux: A minimalistic mkdocs theme

This is a minimalist theme for [mkdocs] made by [@yqshao][yqshao] for his
projects. The look and feel is inspired by the [miniflux] feed reader. See the
live demo of the theme [here].

[mkdocs]: https://www.mkdocs.org/
[yqshao]: https://github.com/yqshao
[miniflux]: https://miniflux.app/
[here]: https://yqshao.github.io/mkdocs-flux/
